
Generate harmless random nicknames, such as CrazyTiger

Examples:

```
FabulousHamster
YellowDolphin
SpaceLlama
StellarLemur
TropicalWombat
```

## Installation

`pip install crazy_tiger`

## Usage

```pycon
>>> import crazy_tiger

>>> crazy_tiger.generate()
'AdorableEagle'

>>> crazy_tiger.generate(case="snake")
'adorable_eagle'
```

## Credits
This project is inspired by the learning platform _Kahoot!_ and its _Friendly Nickname Generator_, which helps to avoid inappropriate nicknames in _Kahoot!_ games.

The word lists used in this project can be accessed here: All credit for the idea and for compiling appropriate words goes to the _Kahoot!_ team.
